### Name: fpca.mle
### Title: Restricted MLE of Functional Principal Components
### Aliases: fpca.mle
### Keywords: methods

### ** Examples


##load data
data(example)

## candidate models
M.set<-c(4,5,6)    
r.set<-c(2,3,4)    

##parameters for fpca.mle
ini.method="EM"
basis.method="bs"
sl.v=rep(0.5,10)
max.step=50
grid.l=seq(0,1,0.01)
grids=seq(0,1,0.002)

##fit candidate models by fpca.mle

data.exp<-example[[1]]
result<-fpca.mle(data.exp, M.set,r.set,ini.method, basis.method,sl.v,max.step,
grid.l,grids)

##rescaled grid

grids.new<-result[[6]]

##model selection result: the true model M=5, r=3 is selected with smallest CV score among all converged models

M<-result[[1]][1]
r<-result[[1]][2]

##compare estimated eigenvalues with the truth

result[[3]]     ## estimated
example[[3]]    ## true

##compare estimated error variance with the truth

result[[4]]        ## estimated
example[[6]]^2     ## true

##plot: compare estimated eigenfunctions with the truth

eigenf<-example[[2]]  ##true
par(mfrow=c(2,2))
for(i in 1:r){
plot(grids.new,result[[2]][i,],ylim=range(result[[2]]),xlab="time",ylab=paste("eigenfunction",i))
points(grids, eigenf[i,],col=5,type="o")
}

##plot: compare estimated mean curve with the truth

plot(grids.new,result[[5]],xlab="time",ylab="mean curve",ylim=range(result[[2]]))
points(grids,numeric(length(grids)),col=5)

par(mfrow=c(1,1))

##look at the CV scores and convergence for each model: note that model (M=5, r=4) does not converge. 

result[[7]]   ##CV
result[[8]]   ##convergence



